@@ -24,7 +24,7 @@ function(MC, q = 1, Correction = "Best", Tree = NULL, Normalize = TRUE, Z = NULL
   Total <- sum(Communities*MC$Wi)
   
   Entropy <- list(
-    MetaCommunity = deparse(substitute(MC)),
+    MetaCommunity = ArgumentOriginalName(MC),
     Method = Method,
     Type = "beta",
     Order = q,
@@ -35,9 +35,9 @@ function(MC, q = 1, Correction = "Best", Tree = NULL, Normalize = TRUE, Z = NULL
     Total=Total
   )
   if(!is.null(Tree))
-    Entropy$Tree <- deparse(substitute(Tree)) 
+    Entropy$Tree <- ArgumentOriginalName(Tree)
   if(!is.null(Z))
-    Entropy$Z <- deparse(substitute(Z)) 
+    Entropy$Z <- ArgumentOriginalName(Z)
   class(Entropy) <- "MCentropy"
   
   return(Entropy)  
